==> delegate8.7.8.tar.gz: delegate8.7.8/src/builtin.c <==
/*////////////////////////////////////////////////////////////////////////
Copyright (c) 1994-2000 Yutaka Sato
Copyright (c) 1994-2000 Electrotechnical Laboratory (ETL), AIST, MITI
Copyright (c) 2001 National Institute of Advanced Industrial Science and Technology (AIST)

Permission to use, copy, and distribute this material for any purpose
and without fee is hereby granted, provided that the above copyright
notice and this permission notice appear in all copies.
ETL MAKES NO REPRESENTATIONS ABOUT THE ACCURACY OR SUITABILITY OF THIS
MATERIAL FOR ANY PURPOSE.  IT IS PROVIDED "AS IS", WITHOUT ANY EXPRESS
OR IMPLIED WARRANTIES.
////////////////////////////////////////////////////////////////////////*/
/*
#define DEBUG 1
*/
#include "_builtin.c"

static showaddrs();
main(ac,av)
	char *av[];
{
	showaddrs();
	mainX(ac,av);
}

#ifdef DEBUG
#include "../../checktext.c"
#else
static showaddrs(){}
#endif

#ifndef ADMINPASS
#define ADMINPASS 0
#endif
char *get_builtin_ADMINPASS(){
	return ADMINPASS;
}
get_builtin_MADE_TIME(){
	return MADE_TIME;
}

char *get_builtin_data(name,sizep,datep)
	char *name;
	int *sizep,*datep;
{	int i;
	char *file1,*name1,*data1;

	for(i = 0; file1 = get_builtin_file(i); i++){
		name1 = file1 + 16;
		if( strcmp(name,name1) == 0 ){
			data1 = name1 + strlen(name1) + 1;
			sscanf(file1,"%x %x",sizep,datep);
			return data1;
		}
	}
	return 0;
}
scan_builtin_data(name,func,arg1,arg2)
	char *name;
	int (*func)();
	char *arg1,*arg2;
{	char *file1,*name1,*data1;
	int i,size1,date1;

	for(i = 0; file1 = get_builtin_file(i); i++){
		name1 = file1 + 16;
		if( strstr(name1,name) ){
			data1 = name1 + strlen(name1) + 1;
			sscanf(file1,"%x %x",&size1,&date1);
			(*func)(name1,data1,size1,arg1,arg2);
		}
	}
}

==> delegate9.1.0-pre2.tar.gz: delegate9.1.0-pre2/src/builtin.c <==
/*////////////////////////////////////////////////////////////////////////
Copyright (c) 1994-2000 Yutaka Sato
Copyright (c) 1994-2000 Electrotechnical Laboratory (ETL), AIST, MITI
Copyright (c) 2001 National Institute of Advanced Industrial Science and Technology (AIST)

Permission to use, copy, and distribute this material for any purpose
and without fee is hereby granted, provided that the above copyright
notice and this permission notice appear in all copies.
ETL MAKES NO REPRESENTATIONS ABOUT THE ACCURACY OR SUITABILITY OF THIS
MATERIAL FOR ANY PURPOSE.  IT IS PROVIDED "AS IS", WITHOUT ANY EXPRESS
OR IMPLIED WARRANTIES.
////////////////////////////////////////////////////////////////////////*/
#include "ystring.h"

/*
#define DEBUG 1
*/
#include "_builtin.c"

static void showaddrs();
void mainX(int ac,const char *av[]);
int main(int ac,char *av[])
{
	showaddrs();
	mainX(ac,(const char**)av);
	return 0;
}

#ifdef DEBUG
#include "../../checktext.c"
#else
static void showaddrs(){}
#endif

#ifndef ADMINPASS
#define ADMINPASS 0
#endif
const char *get_builtin_ADMINPASS(){
	return ADMINPASS;
}
int get_builtin_MADE_TIME(){
	return MADE_TIME;
}

const char *get_builtin_data(PCStr(name),int *sizep,int *datep)
{	int i;
	const char *file1;
	const char *name1;
	const char *data1;

	for(i = 0; file1 = get_builtin_file(i); i++){
		name1 = file1 + 16;
		if( strcmp(name,name1) == 0 ){
			data1 = name1 + strlen(name1) + 1;
			sscanf(file1,"%x %x",sizep,datep);
			return data1;
		}
	}
	return 0;
}
void scan_builtin_data(PCStr(name),int (*func)(const void*,...),PCStr(arg1),PCStr(arg2))
{	const char *file1;
	const char *name1;
	const char *data1;
	int i,size1,date1;

	for(i = 0; file1 = get_builtin_file(i); i++){
		name1 = file1 + 16;
		if( strstr(name1,name) ){
			data1 = name1 + strlen(name1) + 1;
			sscanf(file1,"%x %x",&size1,&date1);
			(*func)(name1,data1,size1,arg1,arg2);
		}
	}
}
